<?php

// The version number (9_5_0) should match version of the Chilkat extension used, omitting the micro-version number.
// For example, if using Chilkat v9.5.0.48, then include as shown here:
include("chilkat_9_5_0.php");

$glob = new CkGlobal();
$success = $glob->UnlockBundle('CBLMTD.CB1122023_h66ue674lR4z');
if ($success != true) {
    print $glob->lastErrorText() . "\n";
    print  "FAIL\n";
    exit;
}
$status = $glob->get_UnlockStatus();
if ($status == 2) {
    print 'Unlocked using purchased unlock code.' . "\n";
}
$success = true;

$gen = new CkXmlDSigGen();

$gen->put_SigLocation('DTE');
$gen->put_SigLocationMod(0);
$gen->put_SigNamespacePrefix('');
$gen->put_SigNamespaceUri('http://www.w3.org/2000/09/xmldsig#');
$gen->put_SignedInfoCanonAlg('C14N');
$gen->put_SignedInfoDigestMethod('sha1');

// -------- Reference 1 --------
$gen->AddSameDocRef('F053245T33','sha1','','','');

// Provide a certificate + private key. (PFX password is test123)
$cert = new CkCert();
$success = $cert->LoadPfxFile('RAN-2021.pfx','3023');
if ($success != true) {
    print $cert->lastErrorText() . "\n";
    exit;
}

$gen->SetX509Cert($cert,true);

$gen->put_KeyInfoType('X509Data+KeyValue');
$gen->put_X509Type('Certificate');

// Load XML to be signed...
$sbXml = new CkStringBuilder();
$success = $sbXml->LoadFile('D53245.xml','iso-8859-1');
if ($success == false) {
    print 'Failed to load XML file.' . "\n";
    exit;
}

$gen->put_Behaviors('IndentedSignature');

// Sign the XML...
$success = $gen->CreateXmlDSigSb($sbXml);
if ($success != true) {
    print $gen->lastErrorText() . "\n";
    exit;
}

// -----------------------------------------------

// Save the signed XML to a file.
$success = $sbXml->WriteFile('qa_data/xml_dsig/sii_cl/signed1.xml','iso-8859-1',false);

print $sbXml->getAsString() . "\n";

// ----------------------------------------
// Verify the signatures we just produced...
$verifier = new CkXmlDSig();
$success = $verifier->LoadSignatureSb($sbXml);
if ($success != true) {
    print $verifier->lastErrorText() . "\n";
    exit;
}

$numSigs = $verifier->get_NumSignatures();
$verifyIdx = 0;
while ($verifyIdx < $numSigs) {
    $verifier->put_Selector($verifyIdx);
    $verified = $verifier->VerifySignature(true);
    if ($verified != true) {
        print $verifier->lastErrorText() . "\n";
        exit;
    }

    $verifyIdx = $verifyIdx + 1;
}

print 'All signatures were successfully verified.' . "\n";

?>

